![](https://img.shields.io/pypi/v/i-lazy) ![](https://img.shields.io/pypi/pyversions/i-lazy)

# i-lazy Python

| Feature                    | Description                                                                                                                     | Status   |
| -------------------------- | ------------------------------------------------------------------------------------------------------------------------------- | -------- |
| Type Checks and Type Casts | Wrappers and util functions to easy type hints (read: prowess).                                                                 | 🔧 Active |
| DataSchema                 | Schema class to construct dataclass from dictionary. Focuses on flexibility and error handling (vs `pydantic` or `sqlalchemy`). | ✅ Done   |
| (Frozen)ContextDict        | A dictionary class that remembers (the traversed path). Can consider supporting backwards traversal.                            | ✅ Done   |
| DotDict                    | Dictionary that uses dot notation to access attributes. Super userfule for dynamic string substitutions.                        | ✅ Done   |
| deep_merge                 | Recursively merge dictionaries by flattening keys.                                                                              | ✅ Done   |
| Singleton                  | Singleton Manager                                                                                                               | 🔧 Active |